#[non_exhaustive]pub enum JsonDecodeErrorKind {
UnexpectedType,
MissingField,
Number,
}Expand description
The kind of a typed-JSON decoding error.
#[non_exhaustive]: new kinds may be added in a future release.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
UnexpectedType
A value had a different JSON type than the target expected.
MissingField
A required object field was missing.
Number
A number could not be represented by the target type.