#[non_exhaustive]pub enum JsonExtractErrorKind {
Missing,
WrongType {
expected: &'static str,
},
Invalid(PrimitiveError),
}Expand description
Why extracting a typed reliakit-primitives
value from JSON failed.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Missing
The requested object key was not present.
WrongType
The value was present but not the expected JSON shape.
Invalid(PrimitiveError)
The value had the right shape but failed primitive validation.