#[non_exhaustive]pub enum JsonFromStrError {
Parse(JsonError),
Decode(JsonDecodeError),
}Expand description
The error type of from_json_str: either the input
was not valid JSON, or the parsed value did not match the target type.
#[non_exhaustive]: new variants may be added in a future release.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Parse(JsonError)
The input was not valid JSON.
Decode(JsonDecodeError)
The JSON parsed but did not match the target type.