#[non_exhaustive]pub enum JsonNumberError {
OutOfRange,
NotAnInteger,
NotFinite,
InvalidNumber,
}Expand description
An error from a JsonNumber conversion.
#[non_exhaustive]: new kinds may be added in a future release.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
OutOfRange
The value does not fit the target integer type.
NotAnInteger
The value is not an integer (it has a fraction or exponent).
NotFinite
The value is not a finite number (e.g. an exponent that overflows f64).
InvalidNumber
The string is not a valid JSON number.