pub fn from_json_str<T: JsonDecode>(input: &str) -> Result<T, JsonFromStrError>Expand description
Parses JSON text and decodes it into T in one step.
pub fn from_json_str<T: JsonDecode>(input: &str) -> Result<T, JsonFromStrError>Parses JSON text and decodes it into T in one step.